"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/forms/KeyValueEditor.tsx
var KeyValueEditor_exports = {};
__export(KeyValueEditor_exports, {
  KeyValueEditor: () => KeyValueEditor,
  default: () => KeyValueEditor_default
});
module.exports = __toCommonJS(KeyValueEditor_exports);
var import_react = require("react");
var import_icons_material = require("@mui/icons-material");
var import_material = require("@mui/material");
var import_mui = require("tss-react/mui");
var import_jsx_runtime = require("react/jsx-runtime");
var emptyInput = { helptip: null, key: "", value: "" };
var useStyles = (0, import_mui.makeStyles)()((theme) => ({
  spacer: { minWidth: theme.spacing(30) }
}));
var KeyValueEditor = ({ disabled, errortext, initialInput = {}, inputHelpTipsMap = {}, onInputChange, reset }) => {
  const { classes } = useStyles();
  const [inputs, setInputs] = (0, import_react.useState)([{ ...emptyInput }]);
  const [error, setError] = (0, import_react.useState)("");
  (0, import_react.useEffect)(() => {
    const newInputs = Object.keys(initialInput).length ? Object.entries(initialInput).map(([key, value]) => ({ helptip: inputHelpTipsMap[key.toLowerCase()], key, ref: (0, import_react.createRef)(), value })) : [{ ...emptyInput, ref: (0, import_react.createRef)() }];
    setInputs(newInputs);
  }, [JSON.stringify(initialInput), JSON.stringify(inputHelpTipsMap), reset]);
  const onClearClick = () => {
    const changedInputs = [{ ...emptyInput }];
    setInputs(changedInputs);
    const inputObject = reducePairs(changedInputs);
    onInputChange(inputObject);
  };
  const updateInputs = (key, index, event) => {
    let changedInputs = [...inputs];
    const {
      target: { value }
    } = event;
    changedInputs[index][key] = value;
    changedInputs[index].helptip = null;
    const normalizedKey = changedInputs[index].key.toLowerCase();
    if (inputHelpTipsMap[normalizedKey]) {
      changedInputs[index].helptip = inputHelpTipsMap[normalizedKey];
    }
    setInputs(changedInputs);
    const inputObject = reducePairs(changedInputs);
    if (changedInputs.every((item) => item.key && item.value) && changedInputs.length !== Object.keys(inputObject).length) {
      setError("Duplicate keys exist, only the last set value will be submitted");
    } else {
      setError("");
    }
    onInputChange(inputObject);
  };
  const reducePairs = (listOfPairs) => listOfPairs.reduce((accu, item) => ({ ...accu, ...item.value ? { [item.key]: item.value } : {} }), {});
  const addKeyValue = () => {
    const changedInputs = [...inputs, { ...emptyInput, ref: (0, import_react.createRef)() }];
    setInputs(changedInputs);
    setError("");
  };
  const removeInput = (index) => {
    let changedInputs = [...inputs];
    changedInputs.splice(index, 1);
    setInputs(changedInputs);
    const inputObject = reducePairs(changedInputs);
    onInputChange(inputObject);
    setError("");
  };
  return /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { children: [
    inputs.map((input, index) => {
      const hasError = Boolean(index === inputs.length - 1 && (errortext || error));
      const hasRemovalDisabled = !(inputs[index].key && inputs[index].value);
      const Helptip = inputs[index].helptip?.component;
      return /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { className: "key-value-container relative", children: [
        /* @__PURE__ */ (0, import_jsx_runtime.jsxs)(import_material.FormControl, { children: [
          /* @__PURE__ */ (0, import_jsx_runtime.jsx)(import_material.OutlinedInput, { disabled, value: input.key, placeholder: "Key", onChange: (e) => updateInputs("key", index, e), type: "text" }),
          hasError && /* @__PURE__ */ (0, import_jsx_runtime.jsx)(import_material.FormHelperText, { children: errortext || error })
        ] }),
        /* @__PURE__ */ (0, import_jsx_runtime.jsx)(import_material.FormControl, { children: /* @__PURE__ */ (0, import_jsx_runtime.jsx)(import_material.OutlinedInput, { disabled, value: input.value, placeholder: "Value", onChange: (e) => updateInputs("value", index, e), type: "text" }) }),
        inputs.length > 1 && !hasRemovalDisabled ? /* @__PURE__ */ (0, import_jsx_runtime.jsx)(import_material.IconButton, { disabled, onClick: () => removeInput(index), size: "large", children: /* @__PURE__ */ (0, import_jsx_runtime.jsx)(import_icons_material.Clear, { fontSize: "small" }) }) : /* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {}),
        Helptip && /* @__PURE__ */ (0, import_jsx_runtime.jsx)(Helptip, { anchor: { left: -35, top: 15, position: "absolute" }, ...inputs[index].helptip.props })
      ] }, index);
    }),
    /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { className: "key-value-container", children: [
      /* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", { className: classes.spacer, children: /* @__PURE__ */ (0, import_jsx_runtime.jsx)(
        import_material.Fab,
        {
          disabled: disabled || !inputs[inputs.length - 1].key || !inputs[inputs.length - 1].value,
          style: { marginBottom: 10 },
          color: "secondary",
          size: "small",
          onClick: addKeyValue,
          children: /* @__PURE__ */ (0, import_jsx_runtime.jsx)(import_icons_material.Add, {})
        }
      ) }),
      /* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", { className: classes.spacer }),
      inputs.length > 1 ? /* @__PURE__ */ (0, import_jsx_runtime.jsx)("a", { className: "margin-left-small", onClick: onClearClick, children: "clear all" }) : /* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", {})
    ] })
  ] });
};
var KeyValueEditor_default = KeyValueEditor;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  KeyValueEditor
});
//# sourceMappingURL=KeyValueEditor.cjs.map